# Generated by Django 2.1.4 on 2018-12-08 03:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('howl', '0008_auto_20170101_0830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='observer',
            name='operator',
            field=models.CharField(choices=[('EqualOperator', 'Equals'), ('GreaterThanOperator', 'Greater than'), ('LowerThanOperator', 'Lower than')], max_length=32, verbose_name='Operator type'),
        ),
    ]
